| documentation | R Documentation |
documentation
alpha |
How much weight to give to relative abundances; a value
between 0 and 1, inclusive. Setting |
counts |
A numeric matrix of count data where each column is a
feature, and each row is a sample. Any object coercible with
|
cpus |
How many parallel processing threads should be used. The
default, |
cutoff |
The maximum number of observations to consider "rare".
Default: |
digits |
Precision of the returned values, in number of decimal
places. E.g. the default |
pairs |
Which combinations of samples should distances be
calculated for? The default value ( |
power |
Scaling factor for the magnitude of differences between
communities ( |
pseudocount |
The value to add to all counts in |
norm |
Normalize the incoming counts. Options are:
Default: |
margin |
If your samples are in the matrix's rows, set to |
tree |
A |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.