| n_cpus | R Documentation |
A thin wrapper around parallely::availableCores(). If the parallely
package is not installed, then it falls back to
parallel::detectCores(all.tests = TRUE, logical = TRUE). Returns 1 if
pthread support is unavailable or when the number of cpus cannot be
determined.
n_cpus()
A scalar integer, guaranteed to be at least 1.
n_cpus()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.